@@ -4,7 +4,7 @@
 * acp_bots [Português]
 *
 * @package language
-* @version 1.0.2
+* @version 1.0.4
 * @Traduzido por: http://phpbbportugal.com - segundo as normas do Acordo Ortográfico
 * @copyright (c) 2005 phpBB Group
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
@@ -41,34 +41,34 @@ $lang = array_merge($lang, array(
 	'BOTS'						=> 'Gestão de Motores de Busca',
 	'BOTS_EXPLAIN'				=> 'Motores de Busca ou espiões são agentes de pesquisa usados para manter atualizadas as Bases de Dados dos servidores de pesquisa. Estes podem distorcer as estatísticas do número de visitantes, aumentando a carga do servidor e, em algumas situações, provocar erros. Aqui pode definir um tipo especial de utilizador para contornar estes problemas.',
 	'BOT_ACTIVATE'				=> 'Ativar',
-	'BOT_ACTIVE'				=> 'Bot Ativo',
-	'BOT_ADD'					=> 'Adicionar bot',
-	'BOT_ADDED'					=> 'Novo bot adicionado com sucesso.',
+	'BOT_ACTIVE'				=> 'Motor de Busca Ativo',
+	'BOT_ADD'					=> 'Adicionar motor de busca',
+	'BOT_ADDED'					=> 'Novo Motor de Busca adicionado com sucesso.',
 	'BOT_AGENT'					=> 'Agente de partida',
-	'BOT_AGENT_EXPLAIN'			=> 'Uma sequência inciando os agentes de navegadores de bots, são permitidas partidas parciais.',
+	'BOT_AGENT_EXPLAIN'			=> 'Localização na web do rastreio do motor de busca. Correspondências parciais são permitidas.',
 	'BOT_DEACTIVATE'			=> 'Desativar',
-	'BOT_DELETED'				=> 'Bot removido com sucesso.',
-	'BOT_EDIT'					=> 'Editar bots',
-	'BOT_EDIT_EXPLAIN'			=> 'Aqui pode editar ou adicionar novos bots. Pode definir qualquer sequência de agentes e/ou um ou mais endereços de IP (ou grupo de endereços) para coincidir. Cuidado ao definir os parâmetros dos agentes ou endereços. Pode especificar um estilo ou Idioma com os quais o Bot visualizará o seu Fórum. Isto pode reduzir o tráfego de seu site especificando um estilo simples para bots. Lembre-se de especificar permissões para o grupo especial de bots.',
-	'BOT_LANG'					=> 'Idioma do Bot',
-	'BOT_LANG_EXPLAIN'			=> 'O idioma presente no bot quando ele navega.',
+	'BOT_DELETED'				=> 'Motor de Busca removido com sucesso.',
+	'BOT_EDIT'					=> 'Editar Motores de Busca',
+	'BOT_EDIT_EXPLAIN'			=> 'Aqui pode editar ou adicionar novos Motores de Busca. Pode definir qualquer sequência de agentes e/ou um ou mais endereços de IP (ou grupo de endereços) para coincidir. Cuidado ao definir os parâmetros dos agentes ou endereços. Pode especificar um estilo ou Idioma com os quais o Motor de Busca visualizará o seu Fórum. Isto pode reduzir o tráfego de seu site especificando um estilo simples para motores de busca. Lembre-se de especificar permissões para o grupo especial de Motores de Busca.',
+	'BOT_LANG'					=> 'Idioma do Motor de Busca',
+	'BOT_LANG_EXPLAIN'			=> 'O idioma presente no Motor de Busca quando ele navega.',
 	'BOT_LAST_VISIT'			=> 'Última visita',
-	'BOT_IP'					=> 'Endereço do IP do Bot',
+	'BOT_IP'					=> 'Endereço do IP do Motor de Busca',
 	'BOT_IP_EXPLAIN'			=> 'São permitidos nomes parciais se separados por virgulas (,).',
-	'BOT_NAME'					=> 'Nome do Bot',
+	'BOT_NAME'					=> 'Nome do Motor de Busca',
 	'BOT_NAME_EXPLAIN'			=> 'Usado apenas para sua informação.',
 	'BOT_NAME_TAKEN'			=> 'Este nome está a ser usado por um Utilizador e não pode ser usado por um Bot.',
 	'BOT_NEVER'					=> 'Nunca',
-	'BOT_STYLE'					=> 'Estilo do Bot',
-	'BOT_STYLE_EXPLAIN'			=> 'O estilo usado para o Fórum pelo bot.',
-	'BOT_UPDATED'				=> 'Bot existente atualizado com sucesso.',
+	'BOT_STYLE'					=> 'Estilo do Motor de Busca',
+	'BOT_STYLE_EXPLAIN'			=> 'O estilo usado para o Fórum pelo Motor de Busca.',
+	'BOT_UPDATED'				=> 'Motor de Busca existente atualizado com sucesso.',
 
-	'ERR_BOT_AGENT_MATCHES_UA'	=> 'O agente de bot que escolheu é semelhante ao que está a usar atualmente. Por favor ajuste o agente para este bot.',
+	'ERR_BOT_AGENT_MATCHES_UA'	=> 'O agente do motor de busca que escolheu é semelhante ao que está a usar atualmente. Por favor ajuste o agente para este Motor de Busca.',
 	'ERR_BOT_NO_IP'				=> 'O IP que forneceu é inválido ou o hostname não pode ser resolvido.',
 	'ERR_BOT_NO_MATCHES'		=> 'Tem que indicar pelo menos uma descrição do navegador ou um IP para o parâmetro.',
 
-	'NO_BOT'					=> 'O bot selecionado não existe.',
-	'NO_BOT_GROUP'				=> 'O Grupo de bots especial existe.',
+	'NO_BOT'					=> 'O Motor de Busca selecionado não existe.',
+	'NO_BOT_GROUP'				=> 'O Grupo de Motores de Busca especial existe.',
 ));
 
 ?>
\ No newline at end of file
