@@ -4,7 +4,7 @@
 * acp_groups [Português]
 *
 * @package language
-* @version 1.0.2
+* @version 1.0.4
 * @Traduzido por: http://phpbbportugal.com - segundo as normas do Acordo Ortográfico
 * @copyright (c) 2005 phpBB Group
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
@@ -56,7 +56,7 @@ $lang = array_merge($lang, array(
 	'GROUP_COLOR'						=> 'Cor do Grupo',
 	'GROUP_COLOR_EXPLAIN'				=> 'Selecione a cor dos Utilizadores do Grupo. Deixe em branco se não deseja ativar esta opção.',
 	'GROUP_CONFIRM_ADD_USER'			=> 'Tem a certeza de que quer adicionar o Utilizador %1$s para este Grupo?',
-	'GROUP_CONFIRM_ADD_USERS'			=> 'Tem a certeza de que quer adicionar os Utilizadors %1$s para este Grupo?',
+	'GROUP_CONFIRM_ADD_USERS'			=> 'Tem a certeza de que quer adicionar os Utilizadores %1$s para este Grupo?',
 	'GROUP_CREATED'						=> 'O Grupo selecionado foi criado com sucesso.',
 	'GROUP_DEFAULT'						=> 'Selecione este como Grupo Padrão para este Utilizador.',
 	'GROUP_DEFS_UPDATED'				=> 'Grupo Padrão para os Utilizadores selecionados.',
@@ -65,7 +65,7 @@ $lang = array_merge($lang, array(
 	'GROUP_DEMOTE'						=> 'Demitir Líder do Grupo',
 	'GROUP_DESC'						=> 'Descrição do Grupo',
 	'GROUP_DETAILS'						=> 'Informação do Grupo',
-	'GROUP_EDIT_EXPLAIN'				=> 'Aqui pode configurar os Grupos existentes. Alterar o nome (<i>exceto dos Grupos Pré-Definidos, onde o nome não pode ser alterado</i>), descrição e estado (Aberto/Fechado). Também é possível especificar outras opções como a cor, o Rank, etc. As alterações aqui feitas afetarão os Membros do Grupo. De notar que os Membros do Grupo podem alterar os Avatares a não ser que selecione as Permissões de Utilizadores apropriadas.',
+	'GROUP_EDIT_EXPLAIN'				=> 'Aqui pode configurar os Grupos existentes. Alterar o nome (<i>exceto dos Grupos Pré-Definidos, onde o nome não pode ser alterado</i>), descrição e estado (Aberto/Fechado). Também é possível especificar outras opções como a cor, a classificação, etc. As alterações aqui feitas afetarão os Membros do Grupo. De notar que os Membros do Grupo podem alterar os Avatares a não ser que selecione as Permissões de Utilizadores apropriadas.',
 	'GROUP_ERR_USERS_EXIST'				=> 'Os Utilizadores selecionados já são Membros deste Grupo.',
 	'GROUP_FOUNDER_MANAGE'				=> 'Gerir apenas por Fundadores',
 	'GROUP_FOUNDER_MANAGE_EXPLAIN'		=> 'Limitar a Gestão deste Grupo aos Administradores Fundadores. Os Utilizadores que possuem as Permissões de Grupo apropriadas, têm autorização para visualizar este Grupo bem como os seus Membros.',
@@ -91,7 +91,7 @@ $lang = array_merge($lang, array(
 	'GROUP_OPEN'						=> 'Aberto',
 	'GROUP_PENDING'						=> 'Membros Pendentes',
 	'GROUP_PROMOTE'						=> 'Promover a Líder do Grupo',
-	'GROUP_RANK'						=> 'Rank do Grupo',
+	'GROUP_RANK'						=> 'Classificação do Grupo',
 	'GROUP_RECEIVE_PM'					=> 'Grupo autorizado a receber Mensagens Privadas',
 	'GROUP_RECEIVE_PM_EXPLAIN'			=> 'Os Grupos ocultos não podem receber mensagens, mesmo selecionando esta opção.',
 	'GROUP_REQUEST'						=> 'Inscrição',
