@@ -4,7 +4,7 @@
 * acp_permissions [Português]
 *
 * @package language
-* @version 1.0.2
+* @version 1.0.4
 * @Traduzido por: http://phpbbportugal.com - segundo as normas do Acordo Ortográfico
 * @copyright (c) 2005 phpBB Group
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
@@ -85,10 +85,10 @@ $lang = array_merge($lang, array(
 	'ACP_GLOBAL_MODERATORS_EXPLAIN'			=> 'Aqui pode configurar Permissões de Moderadores Globais para Utilizadores e Grupos. Estes são Moderadores normais, exceto se tiverem acesso a todos Fóruns.',
 	'ACP_GROUPS_FORUM_PERMISSIONS_EXPLAIN'	=> 'Aqui pode configurar Permissões de Fóruns para Grupos.',
 	'ACP_GROUPS_PERMISSIONS_EXPLAIN'		=> 'Aqui pode configurar as Permissões Globais dos Grupos - Permissões dos Utilizadores, Permissões Globais e Permissões Administrativas. As Permissões dos Utilizadores incluem o uso de Avatares, envio de Mensagens Privadas, etc. Permissões Globais como a Aprovação de Mensagens, Gestão de Tópicos, Gestão de Expulsões, etc. Por último, as Permissões Administrativas como a alteração de Permissões, definição de BBCodes, Gestão de Fóruns, etc. As Permissões dos Utilizadores individuais apenas devem ser alteradas em ocasiões muito especificas. Adicione os Utilizadores a um Grupo e altere as permissões do Grupo.',
-	'ACP_ADMIN_ROLES_EXPLAIN'				=> 'Aqui pode configurar as tarefas para Permissões Administrativas. Tarefas são Permissões efetivas. Se alterar uma tarefa, altera também as Permissões dos itens associados.',
-	'ACP_FORUM_ROLES_EXPLAIN'				=> 'Aqui pode configurar as tarefas para Permissões dos Fóruns. Tarefas são Permissões efetivas. Se alterar uma tarefa, altera também as Permissões dos itens associados.',
-	'ACP_MOD_ROLES_EXPLAIN'					=> 'Aqui pode configurar as tarefas para Permissões de Moderação. Tarefas são Permissões efetivas. Se alterar uma tarefa, altera também as Permissões dos itens associados.',
-	'ACP_USER_ROLES_EXPLAIN'				=> 'Aqui pode configurar as tarefas para Permissões de Utilizadores. Tarefas são permissões efetivas. Se alterar uma tarefa, altera também as Permissões dos itens associados.',
+	'ACP_ADMIN_ROLES_EXPLAIN'				=> 'Aqui pode criar e configurar as Categorias dos Administradores. Cada Categoria tem as Permissões definidas pelo conjunto de funções selecionadas. Alterando uma função, altera as Permissões dos itens associados.',
+	'ACP_FORUM_ROLES_EXPLAIN'				=> 'Aqui pode criar e configurar as Categorias de acesso aos Fóruns. Cada Categoria tem as Permissões definidas pelo conjunto de funções selecionadas. Alterando uma função, altera as Permissões dos itens associados.',
+	'ACP_MOD_ROLES_EXPLAIN'					=> 'Aqui pode criar e configurar as Categorias dos Moderadores. Cada Categoria tem as Permissões definidas pelo conjunto de funções selecionadas. Alterando uma função, altera as Permissões dos itens associados.',
+	'ACP_USER_ROLES_EXPLAIN'				=> 'Aqui pode criar e configurar as Categorias dos Utilizadores. Cada Categoria tem as Permissões definidas pelo conjunto de funções selecionadas. Alterando uma função, altera as Permissões dos itens associados.',
 	'ACP_USERS_FORUM_PERMISSIONS_EXPLAIN'	=> 'Aqui pode configurar as Permissões de Fóruns para Utilizadores.',
 	'ACP_USERS_PERMISSIONS_EXPLAIN'			=> 'Aqui pode configurar as Permissões Globais para Utilizadores. As Permissões de Utilizadores incluem autorização do uso de Avatares, envio de Mensagens Privadas e etc; Permissões Globais como a aprovação de mensagens, gestão de Tópicos, gestão de Expulsões etc; Por último, as Permissões Administrativas como a alteração de permissões, definição de BBCodes, gestão de Fóruns e etc. Para alterar estas configurações para um grande número de Utilizadores, o sistema de permissões de grupos é o método mais aconselhável. As Permissões dos Utilizadores individuais apenas devem ser alteradas em ocasiões muito especificas. Adicione os Utilizadores a um Grupo e altere as permissões do Grupo.',
 	'ACP_VIEW_ADMIN_PERMISSIONS_EXPLAIN'	=> 'Aqui pode ver as Permissões Administrativas efetivas dadas aos Utilizadores/Grupos selecionados.',
@@ -117,7 +117,7 @@ $lang = array_merge($lang, array(
 	'COPY_PERMISSIONS_FROM'					=> 'Copiar Permissões de',
 	'COPY_PERMISSIONS_TO'					=> 'Aplicar Permissões a',
 
-	'CREATE_ROLE'					=> 'Criar Tarefa',
+	'CREATE_ROLE'					=> 'Criar Categoria',
 	'CREATE_ROLE_FROM'				=> 'Usar Configurações de',
 	'CUSTOM'						=> 'Personalizar',
 
@@ -141,7 +141,7 @@ $lang = array_merge($lang, array(
 	'NO_ROLE_ASSIGNED'				=> 'Sem Tarefas atribuidas',
 	'NO_ROLE_ASSIGNED_EXPLAIN'		=> 'A Configuração para esta Tarefa não alterou as Permissões na direita. Se deseja desativar/excluir todas as Permissões deve utilizar o atalho "Tudo <samp>Não</samp>".',
 	'NO_ROLE_AVAILABLE'				=> 'Sem Tarefas Disponíveis',
-	'NO_ROLE_NAME_SPECIFIED'		=> 'O nome da Tarefa deve ser escrito.',
+	'NO_ROLE_NAME_SPECIFIED'		=> 'Deve inserir o nome da Categoria',
 	'NO_ROLE_SELECTED'				=> 'A Tarefa não foi encontrada.',
 	'NO_USER_GROUP_SELECTED'		=> 'Não selecionou nenhum Utilizador ou Grupo.',
 
@@ -157,64 +157,63 @@ $lang = array_merge($lang, array(
 	'ROLE_ADD_SUCCESS'				=> 'A Tarefa foi adicionada com sucesso.',
 	'ROLE_ASSIGNED_TO'				=> 'Os Utilizadores/Grupos foram atribuídos a %s',
 	'ROLE_DELETED'					=> 'A Tarefa foi excluída com sucesso.',
-	'ROLE_DESCRIPTION'				=> 'Descrição da Tarefa',
+	'ROLE_DESCRIPTION'				=> 'Descrição',
 
-	'ROLE_ADMIN_FORUM'				=> 'Administração de Fóruns',
-	'ROLE_ADMIN_FULL'				=> 'Administração Completa',
-	'ROLE_ADMIN_STANDARD'			=> 'Administração Padrão',
-	'ROLE_ADMIN_USERGROUP'			=> 'Administração de Utilizadores e Grupos',
-	'ROLE_FORUM_BOT'				=> 'Acesso de BOT',
+	'ROLE_ADMIN_FORUM'				=> 'Administrador de Fóruns',
+	'ROLE_ADMIN_FULL'				=> 'Administrador Principal',
+	'ROLE_ADMIN_STANDARD'			=> 'Administrador Secundário',
+	'ROLE_ADMIN_USERGROUP'			=> 'Administrador de Grupos e Utilizadores',
+	'ROLE_FORUM_BOT'				=> 'Acesso para Motores de Busca',
 	'ROLE_FORUM_FULL'				=> 'Acesso Completo',
 	'ROLE_FORUM_LIMITED'			=> 'Acesso Limitado',
 	'ROLE_FORUM_LIMITED_POLLS'		=> 'Acesso Limitado + Votações',
-	'ROLE_FORUM_NOACCESS'			=> 'Sem Acesso',
-	'ROLE_FORUM_ONQUEUE'			=> 'Na Fila de Moderação',
+	'ROLE_FORUM_NOACCESS'			=> 'Acesso Bloqueado',
+	'ROLE_FORUM_ONQUEUE'			=> 'Acesso com Moderação',
 	'ROLE_FORUM_POLLS'				=> 'Acesso Padrão + Votações',
-	'ROLE_FORUM_READONLY'			=> 'Acesso só de Leitura',
+	'ROLE_FORUM_READONLY'			=> 'Acesso de Leitura',
 	'ROLE_FORUM_STANDARD'			=> 'Acesso Padrão',
-	'ROLE_FORUM_NEW_MEMBER'			=> 'Utilizadores Registados Recentemente',
-	'ROLE_MOD_FULL'					=> 'Moderador Completo',
-	'ROLE_MOD_QUEUE'				=> 'Moderador da Fila',
-	'ROLE_MOD_SIMPLE'				=> 'Moderador Simples',
-	'ROLE_MOD_STANDARD'				=> 'Moderador Padrão',
-	'ROLE_USER_FULL'				=> 'Todas as Permissões',
-	'ROLE_USER_LIMITED'				=> 'Permissões Limitadas',
-	'ROLE_USER_NOAVATAR'			=> 'Sem Avatar',
-	'ROLE_USER_NOPM'				=> 'Sem Mensagens Privadas',
-	'ROLE_USER_STANDARD'			=> 'Permissões Padrão',
-	'ROLE_USER_NEW_MEMBER'			=> 'Utilizadores Registados Recentemente',
-
+	'ROLE_FORUM_NEW_MEMBER'			=> 'Acesso para Utilizadores Registados Recentemente',
+	'ROLE_MOD_FULL'					=> 'Moderador Global',
+	'ROLE_MOD_QUEUE'				=> 'Moderador de Fóruns',
+	'ROLE_MOD_SIMPLE'				=> 'Moderador Secundário',
+	'ROLE_MOD_STANDARD'				=> 'Moderador Principal',
+	'ROLE_USER_FULL'				=> 'Utilizador Principal',
+	'ROLE_USER_LIMITED'				=> 'Utilizador Iniciado',
+	'ROLE_USER_NOAVATAR'			=> 'Utilizador Sem Avatar',
+	'ROLE_USER_NOPM'				=> 'Utilizador Sem Mensagens Privadas',
+	'ROLE_USER_STANDARD'			=> 'Utilizador Padrão',
+	'ROLE_USER_NEW_MEMBER'			=> 'Características do Utilizador Registado Recentemente',
 	
-	'ROLE_DESCRIPTION_ADMIN_FORUM'			=> 'Tem acesso às Configurações de Gestão e Permissões de Fóruns.',
-	'ROLE_DESCRIPTION_ADMIN_FULL'			=> 'Tem acesso a todas as funções administrativas neste Fórum. <b>Não recomendado a Administradores Normais</b>.',
-	'ROLE_DESCRIPTION_ADMIN_STANDARD'		=> 'Tem acesso à maior parte das funções administrativas, mas não está autorizado a utilizar ferramentas relacionadas com o Servidor ou o Sistema.',
-	'ROLE_DESCRIPTION_ADMIN_USERGROUP'		=> 'Tem acesso à administração de Utilizadores e Grupos: Pode alterar permissões, configurações, administrar explusões e ranks.',
-	'ROLE_DESCRIPTION_FORUM_BOT'			=> 'Esta Tarefa é recomendada para BOTs e motores de busca.',
-	'ROLE_DESCRIPTION_FORUM_FULL'			=> 'Pode utilizar todas as Funções do Fórum, incluindo criar Anúncios e Tópicos Fixos. Pode ignorar o limite de mensagens. <b>Não recomendado a Utilizadores Normais</b>.',
-	'ROLE_DESCRIPTION_FORUM_LIMITED'		=> 'Pode utilizar algumas Funções do Fórum, mas não pode anexar Ficheiros ou utilizar ícones nas Mensagens.',
-	'ROLE_DESCRIPTION_FORUM_LIMITED_POLLS'	=> 'Como o Acesso Limitado, mas pode criar Votações.',
-	'ROLE_DESCRIPTION_FORUM_NOACCESS'		=> 'Não pode ver nem entrar no Fórum.',
-	'ROLE_DESCRIPTION_FORUM_ONQUEUE'		=> 'Pode utilizar a maior parte das Funções do Fórum, incluindo os Anexos, mas os Tópicos e Mensagens têm que ser Aprovadas por um Moderador.',
-	'ROLE_DESCRIPTION_FORUM_POLLS'			=> 'Igual ao Acesso Padrão, mas pode Criar Votações.',
-	'ROLE_DESCRIPTION_FORUM_READONLY'		=> 'Pode ler o Fórum, mas não pode criar Tópicos ou responder a Mensagens.',
-	'ROLE_DESCRIPTION_FORUM_STANDARD'		=> 'Pode utilizar a maior parte das Funções do Fórum, incluindo os Anexos, mas não pode trancar ou eliminar os próprios Tópicos, e Criar Votações.',
+	'ROLE_DESCRIPTION_ADMIN_FORUM'			=> 'Tem acesso às funções de Gestão e Permissões de Fóruns.',
+	'ROLE_DESCRIPTION_ADMIN_FULL'			=> 'Tem acesso a todas as funções administrativas neste Fórum. <b>Recomendado para Fundadores</b>.',
+	'ROLE_DESCRIPTION_ADMIN_STANDARD'		=> 'Tem acesso às funções administrativas, mas não às relacionadas com o Servidor ou o Sistema.',
+	'ROLE_DESCRIPTION_ADMIN_USERGROUP'		=> 'Tem acesso às funções de administração de Utilizadores e Grupos. Pode alterar permissões, configurações, administrar expulsões e classificações.',
+	'ROLE_DESCRIPTION_FORUM_BOT'			=> 'Acesso recomendado a Motores de Busca.',
+	'ROLE_DESCRIPTION_FORUM_FULL'			=> 'Pode utilizar todas as Funções do Fórum. Criar Anúncios e Tópicos Fixos e ignorar o limite de mensagens. <b>Não recomendado a Utilizadores Normais</b>.',
+	'ROLE_DESCRIPTION_FORUM_LIMITED'		=> 'Pode utilizar algumas funções do Fórum. Não pode anexar ficheiros ou utilizar ícones nas Mensagens.',
+	'ROLE_DESCRIPTION_FORUM_LIMITED_POLLS'	=> 'Pode utilizar algumas funções do Fórum. Não pode anexar ficheiros ou utilizar ícones nas mensagens. Pode criar Votações.',
+	'ROLE_DESCRIPTION_FORUM_NOACCESS'		=> 'Não pode ver o Fórum (invisível).',
+	'ROLE_DESCRIPTION_FORUM_ONQUEUE'		=> 'Pode utilizar a maior parte das Funções do Fórum, incluindo os Anexos, mas os Tópicos e as Mensagens têm que ser aprovadas por um Moderador.',
+	'ROLE_DESCRIPTION_FORUM_POLLS'			=> 'Pode utilizar a maior parte das Funções do Fórum, incluindo os Anexos. Não pode bloquear ou eliminar os próprios Tópicos. Pode criar votações.',
+	'ROLE_DESCRIPTION_FORUM_READONLY'		=> 'Pode ver e ler o Fórum. Não pode criar Tópicos nem responder às Mensagens.',
+	'ROLE_DESCRIPTION_FORUM_STANDARD'		=> 'Pode utilizar a maior parte das Funções do Fórum, incluindo os Anexos. Não pode bloquear ou eliminar os próprios Tópicos, e criar votações.',
 	'ROLE_DESCRIPTION_FORUM_NEW_MEMBER'		=> 'A função dos membros do Grupo Especial de Utilizadores Registados Recentemente. Contém permissões <b>Nunca</b> para bloquear recursos aos novos utilizadores.',
-	'ROLE_DESCRIPTION_MOD_FULL'				=> 'Pode utilizar todas as Funções de Moderação, incluindo as explusões.',
-	'ROLE_DESCRIPTION_MOD_QUEUE'			=> 'Pode utilizar a Fila de Moderação para validar e Editar Mensagens.',
-	'ROLE_DESCRIPTION_MOD_SIMPLE'			=> 'Pode utilizar apenas as opções Básicas dos Tópicos. Não pode criar Advertências ou utilizar a Fila de Moderação.',
-	'ROLE_DESCRIPTION_MOD_STANDARD'			=> 'Pode utilizar a maior parte das Ferramentas de Moderação, mas não pode Expulsar Utilizadores ou alterar o Autor da Mensagem.',
-	'ROLE_DESCRIPTION_USER_FULL'			=> 'Pode utilizar todas as funções do Fórum disponíveis para utilizadores, incluindo a alteração do Nome do Utilizador ou ignorar o Limite de mensagens. <b>Não recomendado a Utilizadores Normais</b>.',
-	'ROLE_DESCRIPTION_USER_LIMITED'			=> 'Pode utilizar algumas das Funções dos Utilizadores. Não são permitidos anexos, emails ou mensagens urgentes',
-	'ROLE_DESCRIPTION_USER_NOAVATAR'		=> 'Tem funções limitadas e não pode usar Avatar.',
-	'ROLE_DESCRIPTION_USER_NOPM'			=> 'Tem funções limitadas e não está autorizado a utilizar Mensagens Privadas.',
-	'ROLE_DESCRIPTION_USER_STANDARD'		=> 'Pode utilizar a maior parte das Funções, mas não todas as Ferramentas do Utilizador. Não pode por exemplo, alterar o Nome do Utilizador ou ignorar o limite de mensagens.',
+	'ROLE_DESCRIPTION_MOD_FULL'				=> 'Pode utilizar todas as funções de Moderação. Pode fazer expulsões.',
+	'ROLE_DESCRIPTION_MOD_QUEUE'			=> 'Pode utilizar algumas das funções de Moderação. Pode moderar fóruns, validar e editar mensagens.',
+	'ROLE_DESCRIPTION_MOD_SIMPLE'			=> 'Pode utilizar as Funções de Moderação dos Tópicos. Não pode fazer advertências ou moderar fóruns.',
+	'ROLE_DESCRIPTION_MOD_STANDARD'			=> 'Pode utilizar a maioria das funções de Moderação. Não pode fazer expulsões ou alterar o autor das mensagens.',
+	'ROLE_DESCRIPTION_USER_FULL'			=> 'Pode utilizar todas as funções do Utilizador, incluindo a alteração do nome do utilizador ou ignorar o limite de mensagens. <b>Usar só em situações especiais</b>.',
+	'ROLE_DESCRIPTION_USER_LIMITED'			=> 'Pode utilizar algumas das funções do Utilizador. Não pode usar anexos, emails ou mensagens urgentes.',
+	'ROLE_DESCRIPTION_USER_NOAVATAR'		=> 'Pode utilizar algumas das funções do Utilizador. Não pode usar Avatar.',
+	'ROLE_DESCRIPTION_USER_NOPM'			=> 'Pode utilizar algumas das funções do Utilizador. Não pode usar Mensagens Privadas.',
+	'ROLE_DESCRIPTION_USER_STANDARD'		=> 'Pode utilizar a maior parte das funções do Utilizador. Não pode alterar o nome do utilizador ou ignorar o limite de mensagens.',
 	'ROLE_DESCRIPTION_USER_NEW_MEMBER'		=> 'A função dos membros do Grupo Especial de Utilizadores Registados Recentemente. Contém permissões <b>Nunca</b> para bloquear recursos aos novos utilizadores.',
 
-	'ROLE_DESCRIPTION_EXPLAIN'				=> 'Pode escrever uma pequena explicação sobre a tarefa o objetivo da mesma. O Texto será mostrado nas Permissões.',
+	'ROLE_DESCRIPTION_EXPLAIN'				=> 'Pode fazer uma pequena descrição das tarefas atribuídas à categoria. O Texto será mostrado nas Permissões.',
 	'ROLE_DESCRIPTION_LONG'					=> 'A Descrição da tarefa é muito grande. Por Favor, limite seu texto a 4000 caracteres.',
 	'ROLE_DETAILS'							=> 'Detalhes da tarefa',
 	'ROLE_EDIT_SUCCESS'						=> 'A Tarefa foi editada com sucesso.',
-	'ROLE_NAME'								=> 'Nome da Tarefa',
+	'ROLE_NAME'								=> 'Nome da Categoria',
 	'ROLE_NAME_ALREADY_EXIST'				=> 'Uma tarefa nomeada <strong>%s</strong> já existe para o Tipo de Permissão especificado.',
 	'ROLE_NOT_ASSIGNED'						=> 'A Tarefa ainda não foi atribuída.',
 
@@ -226,8 +225,8 @@ $lang = array_merge($lang, array(
 	'SELECT_TYPE'							=> 'Selecionar Tipo',
 	'SET_PERMISSIONS'						=> 'Dar Permissões',
 	'SET_ROLE_PERMISSIONS'					=> 'Dar Permissões da Tarefa',
-	'SET_USERS_PERMISSIONS'					=> 'Dar Permissões dos Utilizadores',
-	'SET_USERS_FORUM_PERMISSIONS'			=> 'Dar Permissões dos Fóruns',
+	'SET_USERS_PERMISSIONS'					=> 'Dar Permissões de Utilizador',
+	'SET_USERS_FORUM_PERMISSIONS'			=> 'Dar Permissões de Utilizador do Fórum',
 
 	'TRACE_DEFAULT'							=> 'Por Padrão, todas as opções estão assinaladas como <samp>NÃO</samp> (unset). Então, a permissão pode ser substituida por outras configurações.',
 	'TRACE_FOR'								=> 'Copiar para',
@@ -274,7 +273,7 @@ $lang = array_merge($lang, array(
 	'TRACE_WHO'								=> 'Quem',
 	'TRACE_TOTAL'							=> 'Total',
 
-	'USERS_NOT_ASSIGNED'					=> 'Nenhum Utilizador atribuído a esta tarefa',
+	'USERS_NOT_ASSIGNED'					=> 'Não há utilizadores com esta tarefa atribuída',
 	'USER_IS_MEMBER_OF_DEFAULT'				=> 'é um Membro dos Grupos Pre-Definidos seguintes',
 	'USER_IS_MEMBER_OF_CUSTOM'				=> 'é um Membro dos Grupos Personalizados pelo Utilizador seguintes',
 
@@ -283,8 +282,8 @@ $lang = array_merge($lang, array(
 	'VIEW_GLOBAL_PERMS'						=> 'Permissões Globais',
 	'VIEW_PERMISSIONS'						=> 'Ver Permissões',
 
-	'WRONG_PERMISSION_TYPE'					=> 'O Tipo de Permissão foi selecionado de forma errada, o phpBB NÃO o consegue processar corretamente.',
-	'WRONG_PERMISSION_SETTING_FORMAT'		=> 'O Tipo de Permissão foi selecionado de forma errada, o phpBB NÃO o consegue processar corretamente.',
+	'WRONG_PERMISSION_TYPE'					=> 'Foi selecionado o tipo de permissão errada.',
+	'WRONG_PERMISSION_SETTING_FORMAT'		=> 'As configurações da permissão estão num formato errado, o phpBB não as consegue processar corretamente.',
 ));
 
 ?>
\ No newline at end of file
