@@ -4,7 +4,7 @@
 * acp_posting [Português]
 *
 * @package language
-* @version 1.0.2
+* @version 1.0.4
 * @Traduzido por: http://phpbbportugal.com - segundo as normas do Acordo Ortográfico
 * @copyright (c) 2005 phpBB Group
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
@@ -71,7 +71,7 @@ $lang = array_merge($lang, array(
 
 	'TOKEN'							=> 'Símbolo',
 	'TOKENS'						=> 'Símbolos',
-	'TOKENS_EXPLAIN'		=> 'Os Símbolos são campos especiais a serem adicionados pelos Utilizadores. Mas estes apenas serão válidos se tiverem as definições correspondentes. Se necessário, pode numerá-los adicionando um número como o último caracter: Exemplo: {Utilizador}, {Utilizador1}.<br /> <br />Pode ainda utilizar estes Símbolos com qualquer sequência de linguagem presente na diretoria /language como esta: {L_<em>&lt;STRINGNAME&gt;</em>} onde <em>&lt;STRINGNAME&gt;</em> é o nome da sequência traduzida que deseja adicionar. Por exemplo, {L_WROTE} será exibido como “wrote” ou traduzido de acordo com a localidade do Utilizador.<br /><br /><strong>Tenha em atenção que apenas os Símbolos listados abaixo podem ser utilizados com os BBCodes personalizados.</strong>',
+	'TOKENS_EXPLAIN'				=> 'Os Símbolos são campos especiais a serem adicionados pelos Utilizadores. Mas estes apenas serão válidos se tiverem as definições correspondentes. Se necessário, pode numerá-los adicionando um número como o último carácter: Exemplo: {Utilizador}, {Utilizador1}.<br /> <br />Pode ainda utilizar estes Símbolos com qualquer sequência de linguagem presente na diretoria /language como esta: {L_<em>&lt;STRINGNAME&gt;</em>} onde <em>&lt;STRINGNAME&gt;</em> é o nome da sequência traduzida que deseja adicionar. Por exemplo, {L_WROTE} será exibido como “Escreveu” ou traduzido de acordo com a localidade do Utilizador.<br /><br /><strong>Tenha em atenção que apenas os Símbolos listados abaixo podem ser utilizados com os BBCodes personalizados.</strong>',
 
 	'TOKEN_DEFINITION'				=> 'O que é que isto pode ser?',
 	'TOO_MANY_BBCODES'				=> 'Não pode criar mais BBCodes. Elimine alguns BBCodes para poder criar outros.',
@@ -193,7 +193,7 @@ $lang = array_merge($lang, array(
 
 // Word censors 
 $lang = array_merge($lang, array( 
-	'ACP_WORDS_EXPLAIN'				=> 'Aqui pode adicionar, editar e apagar palavras que serão automaticamente censuradas no Fórum. Adicionando esta opção, os visitantes continuarão a poder registra-se com Nomes de utilizadores contendo estas palavras. Podem ser utilizados asteriscos (*) aumentando as possibilidades de abranger variações de uma mesma palavra. Por exemplo, testa* abrangerá testar e detesta.',
+	'ACP_WORDS_EXPLAIN'				=> 'Aqui pode adicionar, editar e apagar palavras que serão automaticamente censuradas no Fórum. Adicionando esta opção, os visitantes continuarão a poder registar-se com Nomes de utilizadores contendo estas palavras. Podem ser utilizados asteriscos (*) aumentando as possibilidades de abranger variações de uma mesma palavra. Por exemplo, testa* abrangerá testar e detesta.',
 	'ADD_WORD'						=> 'Adicionar nova Palavra',
 
  	'EDIT_WORD'						=> 'Editar Palavra Censurada',
@@ -213,24 +213,24 @@ $lang = array_merge($lang, array(
 
 // Ranks 
 $lang = array_merge($lang, array( 
-	'ACP_RANKS_EXPLAIN'				=> 'Aqui poderá adicionar, editar, visualizar e apagar ranks. Pode também criar ranks Personalizados que podem ser aplicados a um Utilizador Ferramentas de Administração de Utilizadores.',
-	'ADD_RANK'						=> 'Adicionar novo Rank',
+	'ACP_RANKS_EXPLAIN'				=> 'Aqui poderá adicionar, editar, visualizar e apagar classificações. Pode também criar classificações personalizadas que podem ser aplicados a um Utilizador nas Ferramentas de Administração de Utilizadores.',
+	'ADD_RANK'						=> 'Adicionar nova classificação',
 
-	'MUST_SELECT_RANK'				=> 'Tem de selecionar um Rank.',
+	'MUST_SELECT_RANK'				=> 'Tem de selecionar uma classificação.',
 
-	'NO_ASSIGNED_RANK'				=> 'Nenhum Rank Especial existente.',
-	'NO_RANK_TITLE'					=> 'Te, que escrever o Título do Rank.',
-	'NO_UPDATE_RANKS'				=> 'O Rank foi apagado com sucesso. De qualquer modo, os registos que utilizavam este rank não foram atualizados. Tem que atualizar os ranks nestes registos manualmente.',
+	'NO_ASSIGNED_RANK'				=> 'Nenhuma Classificação Especial existente.',
+	'NO_RANK_TITLE'					=> 'Tem que escrever o Título da Classificação.',
+	'NO_UPDATE_RANKS'				=> 'A classificação foi apagada com sucesso. De qualquer modo, os registos que utilizavam esta classificação não foram atualizados. Tem que atualizar as classificações nestes registos manualmente.',
 
-	'RANK_ADDED'					=> 'O Rank foi adicionado com sucesso.',
-	'RANK_IMAGE'					=> 'Imagem do Rank',
-	'RANK_IMAGE_EXPLAIN'			=> 'Imagem do Rank (relativo à pasta raíz do phpBB).',
+	'RANK_ADDED'					=> 'A classificação foi adicionada com sucesso.',
+	'RANK_IMAGE'					=> 'Imagem da Classificação',
+	'RANK_IMAGE_EXPLAIN'			=> 'Imagem da Classificação (relativo à pasta raíz do phpBB).',
 	'RANK_IMAGE_IN_USE'		=> '(em uso)',
 	'RANK_MINIMUM'					=> 'Número Mínimo de Mensagens',
-	'RANK_REMOVED'					=> 'O Rank foi apagado com sucesso.',
-	'RANK_SPECIAL'					=> 'Escreva um Rank Especial',
-	'RANK_TITLE'					=> 'Título do Rank',
-	'RANK_UPDATED'					=> 'O Rank foi atualizado com sucesso.',
+	'RANK_REMOVED'					=> 'A classificação foi apagada com sucesso.',
+	'RANK_SPECIAL'					=> 'Escreva uma Classificação Especial',
+	'RANK_TITLE'					=> 'Título da Classificação',
+	'RANK_UPDATED'					=> 'A Classificação foi atualizada com sucesso.',
 )); 
 
 // Disallow Usernames 
