@@ -4,7 +4,7 @@
 * acp_profile [Português]
 *
 * @package language
-* @version 1.0.2
+* @version 1.0.4
 * @Traduzido por: http://phpbbportugal.com - segundo as normas do Acordo Ortográfico
 * @copyright (c) 2005 phpBB Group
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
@@ -47,13 +47,13 @@ $lang = array_merge($lang, array(
 	'BOOL_TYPE_EXPLAIN'				=> 'Defina o tipo, entre uma caixa de seleção (checkbox) ou botões de rádio (radio). Uma caixa só será apresentada se estiver marcada para um determinado Utilizador. Nesse caso a <strong>segunda</strong> opção de linguagem será utilizada. Os Botões de rádio são apresentados, independentemente dos seus valores.',
 
 	'CHANGED_PROFILE_FIELD'			=> 'O Campo do Perfil foi modificado com sucesso.',
-	'CHARS_ANY'						=> 'Qualquer Caractere',
+	'CHARS_ANY'						=> 'Qualquer carácter',
 	'CHECKBOX'						=> 'Checkbox',
 	'COLUMNS'						=> 'Colunas',
 	'CP_LANG_DEFAULT_VALUE'			=> 'Valor Padrão',
 	'CP_LANG_EXPLAIN'				=> 'Descrição do Campo',
 	'CP_LANG_EXPLAIN_EXPLAIN'		=> 'A Explicação para este Campo será exibida ao Utilizador.',
-	'CP_LANG_NAME'					=> 'Título do Campo será mostrado ao Utilizador',
+	'CP_LANG_NAME'					=> 'Título do Campo que será mostrado ao Utilizador',
 	'CP_LANG_OPTIONS'				=> 'Opções',
 	'CREATE_NEW_FIELD'				=> 'Criar novo Campo',
 	'CUSTOM_FIELDS_NOT_TRANSLATED'	=> 'Os Campos do Perfil não foram totalmente traduzidos. Por Favor, escreva a informação solicitada clicando no atalho &quot;Traduzir&quot;.',
@@ -69,11 +69,11 @@ $lang = array_merge($lang, array(
 	'DISPLAY_AT_REGISTER_EXPLAIN'	=> 'Se esta opção estiver ativa, o Campo será exibido no Registo pode ser alterado no Painel de Controlo do Utilizador.',
 	'DISPLAY_ON_VT'					=> 'Exibir na página viewtopic',
 	'DISPLAY_ON_VT_EXPLAIN'			=> 'Caso esta opção esteja ativa, o campo irá ser exibido no mini-perfil na página de Tópicos.',
-	'DISPLAY_PROFILE_FIELD'			=> 'Exibir publicamente campo do perfil',
-	'DISPLAY_PROFILE_FIELD_EXPLAIN'	=> 'O Campo do Perfil será visualizado nos Tópicos, Perfis e Lista de Membros, se isto estiver ativo com as configurações de carga. Apenas exibindo com o Perfil dos utilizadores estará padronalmente ativo.',
+	'DISPLAY_PROFILE_FIELD'			=> 'Exibir publicamente o campo do perfil',
+	'DISPLAY_PROFILE_FIELD_EXPLAIN'	=> 'O Campo do Perfil será visualizado nos Tópicos, Perfis e Lista de Membros, se isto estiver ativo com as configurações de carga.',
 	'DROPDOWN_ENTRIES_EXPLAIN'		=> 'Escreva as suas Opções agora, todas elas numa linha.',
 
-	'EDIT_DROPDOWN_LANG_EXPLAIN'	=> 'Por Favor, note que pode alterar os seus textos de Opções e também pode adicionar novas opções ao fim. Não é aconselhavel adicionar novas Opções dentre outras opções existentes - isto pode resultar em opções defeituosas exibidas aos utilizadores. Isto pode também acontecer se apagar opções dentre outras. Excluindo opções do fim, resultará em Utilizadores com este item revertido ao padrão inicial.',
+	'EDIT_DROPDOWN_LANG_EXPLAIN'	=> 'Por Favor, note que pode alterar os seus textos de Opções e também pode adicionar novas opções ao fim. Não é aconselhavel adicionar novas Opções dentre outras opções existentes - isto pode resultar em opções defeituosas exibidas aos utilizadores. Isto pode também acontecer se apagar opções no meio de outras. Excluindo opções do fim, resultará em Utilizadores com este item revertido ao padrão inicial.',
 	'EMPTY_FIELD_IDENT'				=> 'Identificação do Campo vazia',
 	'EMPTY_USER_FIELD_NAME'			=> 'Por Favor, dê um Título ao Campo',
 	'ENTRIES'						=> 'Entradas',
@@ -83,14 +83,14 @@ $lang = array_merge($lang, array(
 	'FIELD_DATE'					=> 'Data',
 	'FIELD_DESCRIPTION'				=> 'Descrição do Campo',
 	'FIELD_DESCRIPTION_EXPLAIN'		=> 'A explicação para este Campo será mostrada ao Utilizador.',
-	'FIELD_DROPDOWN'				=> 'Caixa de rolagem',
+	'FIELD_DROPDOWN'				=> 'Menu Suspenso',
 	'FIELD_IDENT'					=> 'Identificação do Campo',
 	'FIELD_IDENT_ALREADY_EXIST'		=> 'A Identificação do Campo selecionada já existe. Por Favor, escolha outro nome.',
 	'FIELD_IDENT_EXPLAIN'			=> 'A Identificação do Campo é um nome para identificar o Campo do Perfil com a Base de Dados e os Templates.',
 	'FIELD_INT'						=> 'Números',
 	'FIELD_LENGTH'					=> 'Comprimento da Caixa de Entrada',
 	'FIELD_NOT_FOUND'				=> 'O Campo de Perfil não foi encontrado.',
-	'FIELD_STRING'					=> 'Campo de Texto Individual',
+	'FIELD_STRING'					=> 'Campo de Texto Simples',
 	'FIELD_TEXT'					=> 'Área de Texto',
 	'FIELD_TYPE'					=> 'Tipo do Campo',
 	'FIELD_TYPE_EXPLAIN'			=> 'Não pode alterar o tipo de Perfil depois.',
@@ -114,8 +114,8 @@ $lang = array_merge($lang, array(
 	'NO_FIELD_ENTRIES'				=> 'Sem entradas definidas',
 	'NO_FIELD_ID'					=> 'Não foi especificada a Identificação do Campo.',
 	'NO_FIELD_TYPE'					=> 'Não foi especificado o Tipo de Campo.',
-	'NO_VALUE_OPTION'				=> 'Opção igual a um valor no escrito',
-	'NO_VALUE_OPTION_EXPLAIN'		=> 'Valor para um no escrito. Se o Campo for solicitado, o Utilizador receberá um erro se ele escolher a opção selecionada aqui.',
+	'NO_VALUE_OPTION'				=> 'Campo a evitar pelo Utilizador',
+	'NO_VALUE_OPTION_EXPLAIN'		=> 'Se este campo for seleccionado o Utilizador recebe um erro, tendo que escolher outro para continuar.',
 	'NUMBERS_ONLY'					=> 'Apenas Números (0-9)',
 
 	'PROFILE_BASIC_OPTIONS'			=> 'Opções Básicas',
@@ -132,6 +132,8 @@ $lang = array_merge($lang, array(
 
 	'SAVE'							=> 'Guardar',
 	'SECOND_OPTION'					=> 'Segunda Opção',
+	'SHOW_NOVALUE_FIELD'			=> 'Mostrar campo se nenhum valor for seleccionado',
+	'SHOW_NOVALUE_FIELD_EXPLAIN'	=> 'Define se deve ser mostrado o campo do perfil, caso nenhum valor nos campos opcionais ou obrigatórios for selecionado.',
 	'STEP_1_EXPLAIN_CREATE'			=> 'Aqui pode escrever os primeiros parâmetros básicos de seu novo Campo no Perfil. Estas informações são necessárias para a segunda etapa, onde poderá inserir as opções restantes e prever o seu Campo mais adiante.',
 	'STEP_1_EXPLAIN_EDIT'			=> 'Aqui pode alterar os parâmetros básicos de seu campo no Perfil. As opções relevantes são re-calculadas com a segunda etapa, onde poderá prever e testar as suas novas configurações.',
 	'STEP_1_TITLE_CREATE'			=> 'Adicionar Campo de Perfil',
