@@ -4,7 +4,7 @@
 * acp_search [Português]
 *
 * @package language
-* @version 1.0.2
+* @version 1.0.4
 * @Traduzido por: http://phpbbportugal.com - segundo as normas do Acordo Ortográfico
 * @copyright (c) 2005 phpBB Group
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
@@ -45,7 +45,7 @@ $lang = array_merge($lang, array(
 	'CONFIRM_SEARCH_BACKEND'				=> 'Deseja alterar o modo de pesquisa? Depois de modificar o seu modo de pesquisa, deverá criar um novo índice para o novo modo selecionado. Se não planeia voltar ao seu modo de pesquisa antigo, poderá excluí-lo.',
 	'CONTINUE_DELETING_INDEX'				=> 'Continuar processo de exclusão de índice',
 	'CONTINUE_DELETING_INDEX_EXPLAIN'		=> 'Um processo de exclusão de índice foi iniciado. Para aceder à página de índice da pesquisa novamente deve completar o processo ou cancelá-lo.',
-	'CONTINUE_INDEXING'						=> 'Continue previous indexing process',
+	'CONTINUE_INDEXING'						=> 'Continuar com o processo de indexar anterior',
 	'CONTINUE_INDEXING_EXPLAIN'				=> 'Um processo de criação de índice foi iniciado. Para aceder à página de índice da pesquisa novamente deve completar o processo ou cancelá-lo.',
 	'CREATE_INDEX'							=> 'Criar Índice',
 
@@ -58,8 +58,8 @@ $lang = array_merge($lang, array(
 	'FULLTEXT_MYSQL_TOTAL_POSTS'			=> 'Número Total de Mensagens indexadas',
 	'FULLTEXT_MYSQL_MBSTRING'				=> 'Suporte para non-latin UTF-8 caracteres utilizando mbstring:',
 	'FULLTEXT_MYSQL_PCRE'					=> 'Suporte para non-latin UTF-8 caracteres utilizando PCRE:',
-	'FULLTEXT_MYSQL_MBSTRING_EXPLAIN'		=> 'Se o PCRE não tiver propriedades de caractere unicode, o sistema de pesquisa tentará utilizar o sistema de expressões regulares mbstring.',
-	'FULLTEXT_MYSQL_PCRE_EXPLAIN'			=> 'Esta pesquisa exige propriedades de caractere PCRE, que somente estão presentes nas versões superiores a PHP 4.4, 5.1, se quer procurar non-latin caráter.',
+	'FULLTEXT_MYSQL_MBSTRING_EXPLAIN'		=> 'Se o PCRE não tiver propriedades de carácter unicode, o sistema de pesquisa tentará utilizar o sistema de expressões regulares mbstring.',
+	'FULLTEXT_MYSQL_PCRE_EXPLAIN'			=> 'Esta pesquisa exige propriedades de carácter PCRE, que somente estão presentes nas versões superiores a PHP 4.4, 5.1, se quer procurar non-latin carácter.',
     'FULLTEXT_MYSQL_MIN_SEARCH_CHARS_EXPLAIN'   => 'Número mínimo de caracteres das palavras que são indexados para pesquisa. A alteração desta configuração tem de ser feita no mysql por si ou pelo administrador do servidor.',
     'FULLTEXT_MYSQL_MAX_SEARCH_CHARS_EXPLAIN'   => 'Número máximo de caracteres das palavras que são indexados para pesquisa. A alteração desta configuração tem de ser feita no mysql por si ou pelo administrador do servidor.',
 
@@ -71,14 +71,14 @@ $lang = array_merge($lang, array(
 	'INDEXING_IN_PROGRESS_EXPLAIN'			=> 'A pesquisa está a indexar todas as mensagens do Fórum. Esta ação pode levar de alguns minutos a várias horas, dependendo do tamanho do Fórum.',
 
 	'LIMIT_SEARCH_LOAD'						=> 'Limite de carga do sistema da Página de Pesquisa',
-	'LIMIT_SEARCH_LOAD_EXPLAIN'				=> 'Se a carga do sistema de 1 minuto exceder este valor, a página de pesquisa irá ficar offline, 1.0 igual ~100% utilização de um processador. Isto apenas funciona em Servidores UNIX.',
+	'LIMIT_SEARCH_LOAD_EXPLAIN'				=> 'Se a carga do sistema de 1 minuto exceder este valor, a página de pesquisa irá desligar-se, 1.0 igual ~100% utilização de um processador. Isto apenas funciona em Servidores UNIX.',
 
-	'MAX_SEARCH_CHARS'						=> 'Núm. Máximo de Caracteres indexandos por pesquisa',
-	'MAX_SEARCH_CHARS_EXPLAIN'				=> 'Palavras com não mais que estes pequenos caracteres serão indexandos para pesquisa.',
+	'MAX_SEARCH_CHARS'						=> 'Núm. Máximo de Caracteres indexados por pesquisa',
+	'MAX_SEARCH_CHARS_EXPLAIN'				=> 'Palavras com não mais que estes pequenos caracteres serão indexadas para pesquisa.',
 	'MAX_NUM_SEARCH_KEYWORDS'				=> 'Número máximo permitido de palavras-chave',
 	'MAX_NUM_SEARCH_KEYWORDS_EXPLAIN'		=> 'Número máximo de palavras que o utilizador pode usar nas pesquisas. O valor 0 permite um número ilimitado de palavras.',
-	'MIN_SEARCH_CHARS'						=> 'Núm. Mín. de Caracteres indexandos por pesquisa',
-	'MIN_SEARCH_CHARS_EXPLAIN'				=> 'Palavras com menos que estes pequenos caracteres serão indexandos para pesquisa.',
+	'MIN_SEARCH_CHARS'						=> 'Núm. Mín. de Caracteres indexados por pesquisa',
+	'MIN_SEARCH_CHARS_EXPLAIN'				=> 'Palavras com menos que estes pequenos caracteres serão indexadas para pesquisa.',
 	'MIN_SEARCH_AUTHOR_CHARS'				=> 'Núm. Mínimo de Caracteres do Nome do Autor',
 	'MIN_SEARCH_AUTHOR_CHARS_EXPLAIN'		=> 'Os Utilizadores terão que escrever mais do que estes caracteres do Nome enquanto executando uma pesquisa por autor. Se o Nome do Autor for menos que este número ainda pode pesquisar pelas mensagens do autor, escrevendo o nome de utilizador completo.',
 
@@ -88,7 +88,7 @@ $lang = array_merge($lang, array(
 	'SEARCH_GUEST_INTERVAL_EXPLAIN'			=> 'Número em segundos que um Visitante deverá esperar entre pesquisas. Se um visitante realizar pesquisas todos os outros devem esperar até que o intervalo de tempo passe.',
 	'SEARCH_INDEX_CREATE_REDIRECT'			=> 'Todas as mensagens com o id superior a %1$d serão indexadas agora, do qual %2$d mensagens serão nesta etapa.<br />A taxa atual de indexação é de aproximadamente %3$.1f mensagens por segundo.<br />Indexação em progresso…',
 	'SEARCH_INDEX_DELETE_REDIRECT'			=> 'Todas as mensagens com o id superior a %1$d serão apagadas da indexação da pesquisa.<br />Remoção em progresso…',
-	'SEARCH_INDEX_CREATED'					=> 'Todas as Mensagens foram indexandas na Base de Dados com sucesso.',
+	'SEARCH_INDEX_CREATED'					=> 'Todas as Mensagens foram indexadas na Base de Dados com sucesso.',
 	'SEARCH_INDEX_REMOVED'					=> 'O Índice de Pesquisa foi apagado com sucesso.',
 	'SEARCH_INTERVAL'						=> 'Intervalo de Pesquisas para Utilizadores',
 	'SEARCH_INTERVAL_EXPLAIN'				=> 'Número em segundos que os utilizadores devem esperar entre uma pesquisa e outra. Este intervalo é controlado independentemente para cada utilizador.',
@@ -98,8 +98,8 @@ $lang = array_merge($lang, array(
 	'SEARCH_TYPE_EXPLAIN'					=> 'O phpBB permite-lhe selecionar o modo que será utilizado para a pesquisa de textos nos conteúdos da mensagem. Por padrão, será utilizado apenas o próprio sistema de pesquisas por textos completos.',
 	'SWITCHED_SEARCH_BACKEND'				=> 'O modo de pesquisa foi selecionado com sucesso. Agora, para utilizá-lo terá que certificar-se da existência de um índice para o modo escolhido.',
 
-	'TOTAL_WORDS'							=> 'Número Total de Palavras indexandas',
-	'TOTAL_MATCHES'							=> 'Número Total de Palavras indexandas para relações de Mensagens',
+	'TOTAL_WORDS'							=> 'Número Total de Palavras indexadas',
+	'TOTAL_MATCHES'							=> 'Número Total de Palavras indexadas para relações de Mensagens',
 
 	'YES_SEARCH'							=> 'Ativar Facilidades para Pesquisa',
 	'YES_SEARCH_EXPLAIN'					=> 'Ativar funcionalidades de pesquisa especiais incluindo a pesquisa de Membros.',
