@@ -4,7 +4,7 @@
 * acp_users [Português]
 *
 * @package language
-* @version 1.0.2
+* @version 1.0.4
 * @Traduzido por: http://phpbbportugal.com - segundo as normas do Acordo Ortográfico
 * @copyright (c) 2005 phpBB Group
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
@@ -46,10 +46,10 @@ $lang = array_merge($lang, array(
 	'CANNOT_BAN_ANONYMOUS'			=> 'Não tem permissão para eliminar a conta Visitantes. As Permissões dos Visitantes podem ser definidas no separador Permissões.',
 	'CANNOT_BAN_FOUNDER'			=> 'Não pode expulsar Fundadores.',
 	'CANNOT_BAN_YOURSELF'			=> 'Não pode auto expulsar-se.',
-	'CANNOT_DEACTIVATE_BOT'			=> 'Não pode desativar contas de bots. Desative o bot.',
-	'CANNOT_DEACTIVATE_FOUNDER'		=> 'Não pode desativer contas de Fundador.',
+	'CANNOT_DEACTIVATE_BOT'			=> 'Não pode desativar contas de Motores de Busca. Desative o Motor de Busca.',
+	'CANNOT_DEACTIVATE_FOUNDER'		=> 'Não pode desativar contas de Fundador.',
 	'CANNOT_DEACTIVATE_YOURSELF'	=> 'Não pode desativar sua própria conta.',
-	'CANNOT_FORCE_REACT_BOT'		=> 'Não pode forçar a Reativação de contas de bots. Desative o bot.',
+	'CANNOT_FORCE_REACT_BOT'		=> 'Não pode forçar a Reativação de contas de Motores de Busca. Desative o Motor de Busca.',
 	'CANNOT_FORCE_REACT_FOUNDER'	=> 'Não pode forçar a Reativação de uma conta de Fundador.',
 	'CANNOT_FORCE_REACT_YOURSELF'	=> 'Não pode forçar a Reativação da sua própria conta.',
 	'CANNOT_REMOVE_ANONYMOUS'		=> 'Não pode remover a conta de Utilizador convidado.',
@@ -60,7 +60,7 @@ $lang = array_merge($lang, array(
 
 	'DELETE_POSTS'					=> 'Apagar as Mensagens',
 	'DELETE_USER'					=> 'Apagar Utilizador',
-	'DELETE_USER_EXPLAIN'			=> '<b>Atenção:</b> Esta  operação é irreversível. Não é possível recuperar um Utilizador depois de apagado.',
+	'DELETE_USER_EXPLAIN'			=> '<b>Atenção:</b> Esta operação é irreversível. Não é possível recuperar utilizadores depois de apagados. As Mensagens Privadas enviadas por este utilizador serão apagadas e deixarão de estar disponíveis nos seus destinatários.',
 
 	'FORCE_REACTIVATION_SUCCESS'	=> 'A Reativação foi forçada com sucesso.',
 	'FOUNDER'						=> 'Fundador',
@@ -78,7 +78,7 @@ $lang = array_merge($lang, array(
 
 	'MOVE_POSTS_EXPLAIN'			=> 'Selecione o Fórum para o onde deseja mover todas as Mensagens que este Utilizador fez.',
 
-	'NO_SPECIAL_RANK'				=> 'Sem atribuição de colocação (rank) especial',
+	'NO_SPECIAL_RANK'				=> 'Sem atribuição de classificação especial',
 	'NO_WARNINGS'					=> 'Nenhum Aviso.',
 	'NOT_MANAGE_FOUNDER'			=> 'Tentou gerir um Utilizador Fundador do Fórum. Apenas Fundadores podem gerir outros Fundadores.',
 
@@ -125,6 +125,7 @@ $lang = array_merge($lang, array(
 	'USER_GROUP_SPECIAL'			=> 'O Utilizador é Membro dos Grupos pré-definidos',
 	'USER_LIFTED_NR'				=> 'Removido com sucesso o novo utilizador registado recentemente.',
 	'USER_NO_ATTACHMENTS'			=> 'Não existem Ficheiros a exibir.',
+	'USER_NO_POSTS_TO_DELETE'		=> 'O utilizador não tem mensagens para reter ou excluir.',
 	'USER_OUTBOX_EMPTIED'			=> 'Apagado com sucesso a mensagem privada da caixa de saída.',
 	'USER_OUTBOX_EMPTY'				=> 'A caixa de saída de mensagens privdas está agora vazia.',
 	'USER_OVERVIEW_UPDATED'			=> 'Detalhes do Utilizador foram atualizados.',
@@ -133,8 +134,8 @@ $lang = array_merge($lang, array(
 	'USER_PREFS_UPDATED'			=> 'As preferências do Utilizador foram atualizadas.',
 	'USER_PROFILE'					=> 'Perfil do Utilizador',
 	'USER_PROFILE_UPDATED'			=> 'O Perfil do Utilizador foi atualizado com sucesso.',
-	'USER_RANK'						=> 'Colocação (rank) do Utilizador',
-	'USER_RANK_UPDATED'				=> 'Colocação (rank) do Utilizador atualizada.',
+	'USER_RANK'						=> 'Classificação do Utilizador',
+	'USER_RANK_UPDATED'				=> 'Classificação do Utilizador atualizada.',
 	'USER_SIG_UPDATED'				=> 'A Assinatura do Utilizador foi atualizada com sucesso.',
 	'USER_WARNING_LOG_DELETED'		=> 'Informação não disponível. Possivelmente a entrada de registo foi apagada.',
 	'USER_TOOLS'					=> 'Ferramentas Básicas',
