@@ -4,7 +4,7 @@
 * common [Português]
 *
 * @package language
-* @version 1.0.2
+* @version 1.0.4
 * @Traduzido por: http://phpbbportugal.com - segundo as normas do Acordo Ortográfico
 * @copyright (c) 2005 phpBB Group
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
@@ -54,9 +54,9 @@ $lang = array_merge($lang, array(
 	'6_MONTHS'							=> '6 Meses',
 	'7_DAYS'							=> '7 Dias',
 
-	'ACCOUNT_ALREADY_ACTIVATED'			=> 'O seu registo já está ativo.',
+	'ACCOUNT_ALREADY_ACTIVATED'			=> 'O seu registo já se encontra ativo.',
 	'ACCOUNT_DEACTIVATED'				=> 'O seu registo foi desativado manualmente e apenas pode ser reativado por um Administrador.',
-	'ACCOUNT_NOT_ACTIVATED'				=> 'O seu registo ainda não foi ativado.',
+	'ACCOUNT_NOT_ACTIVATED'				=> 'O seu registo ainda não se encontra activo',
 	'ACP'								=> 'Painel de Administração',
 	'ACTIVE'							=> 'Ativo',
 	'ACTIVE_ERROR'						=> 'Especificou um Utilizador inativo. Se continuar com problemas, contate um Administrador.',
@@ -79,7 +79,7 @@ $lang = array_merge($lang, array(
 	'ATTACHED_IMAGE_NOT_IMAGE'			=> 'O Ficheiro de imagem que anexou é inválido',
 	'AUTHOR'							=> 'Autor',
 	'AUTH_NO_PROFILE_CREATED'			=> 'Não foi possível criar o Perfil do Utilizador.',
-	'AVATAR_DISALLOWED_CONTENT'			=> 'O envio foi recusado porque o Ficheiro foi indentificado como potencialmente malicioso.',
+	'AVATAR_DISALLOWED_CONTENT'			=> 'O envio foi recusado porque o Ficheiro foi identificado como potencialmente malicioso.',
 	'AVATAR_DISALLOWED_EXTENSION'		=> 'A extensão %s não é permitida.',
 	'AVATAR_EMPTY_REMOTE_DATA'			=> 'Avatar não foi enviado, por favor, tente enviar o Ficheiro manualmente.',
 	'AVATAR_EMPTY_FILEUPLOAD'			=> 'O Ficheiro de Avatar enviado está vazio.',
@@ -87,12 +87,12 @@ $lang = array_merge($lang, array(
 	'AVATAR_NOT_UPLOADED'				=> 'O Avatar não foi enviado.',
 	'AVATAR_NO_SIZE'					=> 'Não foi possível obter a largura e a altura do Avatar, por favor, indique-os manualmente.',
 	'AVATAR_PARTIAL_UPLOAD'				=> 'O Ficheiro foi parcialmente enviado.',
-	'AVATAR_PHP_SIZE_NA'				=> 'O Ficheiro do Avatar é muito grande.<br />Não foi possível determinar o tamanho máximo definido pelo PHP no php.ini.',
-	'AVATAR_PHP_SIZE_OVERRUN'			=> 'O Ficheiro do Avatar é muito grande, máximo permitido de envio é %1$d %2$s.<br />Por favor note que isto é definido no php.ini e não pode ser alterado.',
+	'AVATAR_PHP_SIZE_NA'				=> 'O Ficheiro do Avatar é demasiado grande.<br />Não foi possível determinar o tamanho máximo definido pelo PHP no php.ini.',
+	'AVATAR_PHP_SIZE_OVERRUN'			=> 'O Ficheiro do Avatar é demasiado grande, sendo o máximo permitido de envio %1$d %2$s.<br />Por favor, note que isto é definido no php.ini e não pode ser alterado.',
 	'AVATAR_URL_INVALID'				=> 'A URL que especificou é inválida.',
 	'AVATAR_URL_NOT_FOUND'				=> 'O Ficheiro indicado não foi encontrado.',
 	'AVATAR_WRONG_FILESIZE'				=> 'O tamanho do Avatar deve estar entre 0 e %1d %2s.',
-	'AVATAR_WRONG_SIZE'					=> 'O Avatar deve ser no mínimo %1$d pixels de Largura, %2$d pixels Altura e no máximo %3$d pixels de Largura e %4$d pixels de Altura.',
+	'AVATAR_WRONG_SIZE'					=> 'O Avatar deve ser no mínimo %1$d píxeis de Largura, %2$d píxeis Altura e no máximo %3$d píxeis de Largura e %4$d píxeis de Altura.',
 
 	'BACK_TO_TOP'						=> 'Topo',
 	'BACK_TO_PREV'						=> 'Voltar à página anterior',
@@ -170,14 +170,14 @@ $lang = array_merge($lang, array(
 	'ERR_CHANGING_DIRECTORY'			=> 'Não foi possível alterar a diretoria.',
 	'ERR_CONNECTING_SERVER'				=> 'Erro ao ligar-se ao servidor.',
 	'ERR_JAB_AUTH'						=> 'Não foi autorizado a entrar no servidor Jabber.',
-	'ERR_JAB_CONNECT'					=> 'Não foi possivel fazer a ligacão ao servidor Jabber.',
+	'ERR_JAB_CONNECT'					=> 'Não foi possivel fazer a ligação ao servidor Jabber.',
 	'ERR_UNABLE_TO_LOGIN'				=> 'Ocorreu um erro no acesso. Nome de Utilizador ou Senha incorretos.',
 	'ERR_UNWATCHING'					=> 'Um erro ocorreu durante o cancelamento da subscrição.',
 	'ERR_WATCHING'						=> 'Um erro ocorreu durante a subscrição.',	
 	'ERR_WRONG_PATH_TO_PHPBB'			=> 'O local do script phpBB indicado parece não ser válido.',
 	'EXPAND_VIEW'						=> 'Ver mais detalhes',
 	'EXTENSION'							=> 'Extensão',
-	'EXTENSION_DISABLED_AFTER_POSTING'	=> 'A extenção <b>%s</b> foi desativada e não pode ser exibida.',
+	'EXTENSION_DISABLED_AFTER_POSTING'	=> 'A extensão <b>%s</b> foi desativada e não pode ser exibida.',
 
 	'FAQ'								=> 'FAQ',
 	'FAQ_EXPLAIN'						=> 'Questões Mais Frequentes',
@@ -192,7 +192,7 @@ $lang = array_merge($lang, array(
 	'FORM_INVALID'						=> 'Campo inválido. Tente submeter novamente.',
 	'FORUM'								=> 'Fórum',
 	'FORUMS'							=> 'Fóruns',
-	'FORUMS_MARKED'						=> 'Os Fóruns selecionados foram marcados como lidos.',
+	'FORUMS_MARKED'						=> 'Os Fóruns foram marcados como lidos.',
 	'FORUM_CAT'							=> 'Categoria do Fórum',
 	'FORUM_INDEX'						=> 'Índice do Fórum',
 	'FORUM_LINK'						=> 'Endereço do Fórum',
@@ -248,7 +248,7 @@ $lang = array_merge($lang, array(
 	'GUEST_USER_ONLINE'					=> 'Há %d visitante online',
 	'GUEST_USER_TOTAL'					=> '%d visitante',
 	'G_ADMINISTRATORS'					=> 'Administrador',
-	'G_BOTS'							=> 'Bots',
+	'G_BOTS'							=> 'Motores de Busca',
 	'G_GUESTS'							=> 'Visitantes',
 	'G_REGISTERED'						=> 'Utilizadores',
 	'G_REGISTERED_COPPA'				=> 'Utilizadores COPPA Registados',
@@ -267,7 +267,7 @@ $lang = array_merge($lang, array(
 	'HIDE_GUESTS'						=> 'Visitantes invisíveis',
 	'HIDE_ME'							=> 'Ocultar o meu estado nesta sessão',
 	'HOURS'								=> 'Horas',
-	'HOME'								=> 'Home',
+	'HOME'								=> 'Página Principal',
 
 	'ICQ'								=> 'ICQ',
 	'ICQ_STATUS'						=> 'Estado do ICQ',
@@ -304,10 +304,10 @@ $lang = array_merge($lang, array(
 	'LOCK_POST'							=> 'Bloquear Mensagem',
 	'LOCK_POST_EXPLAIN'					=> 'Edição Prévia',
 	'LOCK_TOPIC'						=> 'Bloquear Tópico',
-	'LOGIN'								=> 'Entrar',
+	'LOGIN'								=> 'Ligue-se',
 	'LOGIN_CHECK_PM'					=> 'Ver Mensagens Privadas.',
 	'LOGIN_CONFIRMATION'				=> 'Confirmação de acesso',
-	'LOGIN_CONFIRM_EXPLAIN'				=> 'Para prevenir ataques brute force o Administrador exige o código de confirmação após sucessivas tentativas falhadas de acesso. O código é exibido na imagem abaixo. Se tiver problemas em ver esta imagem, por favor, contate um %sAdministrador%s.', // unused
+	'LOGIN_CONFIRM_EXPLAIN'				=> 'Para prevenir ataques "brute force" o Administrador exige o código de confirmação após sucessivas tentativas falhadas de acesso. O código é exibido na imagem abaixo. Se tiver problemas em ver esta imagem, por favor, contate um %sAdministrador%s.', // unused
     'LOGIN_ERROR_ATTEMPTS'				=> 'Excedeu o número máximo de tentativas de acesso. Além do seu nome de Utilizador e Senha tem de resolver o CAPTCHA abaixo',
 	'LOGIN_ERROR_EXTERNAL_AUTH_APACHE'	=> 'Não foi autenticado pelo Apache.',
 	'LOGIN_ERROR_PASSWORD'				=> 'A Senha introduzida não está correta, tente novamente. Se continuar com problemas, contate um Administrador.',
@@ -318,7 +318,7 @@ $lang = array_merge($lang, array(
 	'LOGIN_VIEWFORUM'					=> 'Para ver o conteúdo completo deste Fórum é necessário estar ligado.',
 	'LOGIN_EXPLAIN_EDIT'				=> 'Para editar Mensagens neste Fórum tem de estar registado e ligado.',
 	'LOGIN_EXPLAIN_VIEWONLINE'			=> 'Para aparecer na lista tem de estar registado e ligado.',
-	'LOGOUT'							=> 'Sair',
+	'LOGOUT'							=> 'Desligar Sessão',
 	'LOGOUT_USER'						=> 'Sair [ %s ]',
 	'LOG_ME_IN'							=> 'Na próxima visita entrar automaticamente',
 
@@ -346,7 +346,7 @@ $lang = array_merge($lang, array(
 	'MSNM'								=> 'MSM/WLM',
 
 	'NA'								=> 'N/A',
-	'NEWEST_USER'						=> '<b>%s</b> é o(a) nosso(a) Utilizador(a) mais recente. Bem vindo(a) ao <b>Fórum</b>',
+	'NEWEST_USER'						=> '<b>%s</b> é o(a) nosso(a) Utilizador(a) mais recente. Bem-vindo(a) ao <b>Fórum</b>',
 	'NEW_MESSAGE'						=> 'Nova Mensagem',
 	'NEW_MESSAGES'						=> 'Novas Mensagens',
 	'NEW_PM'							=> '<b>%d</b> mensagem privada nova',
@@ -359,10 +359,10 @@ $lang = array_merge($lang, array(
 	'NO'								=> 'Não',
 	'NOT_ALLOWED_MANAGE_GROUP'			=> 'Não está autorizado a administrar este grupo do “Painel de Administração”.',
 	'NOT_AUTHORISED'					=> 'Não está autorizado a aceder esta área.',
-	'NOT_WATCHING_FORUM'				=> 'Não se inscreveu para receber atualizações deste Fórum.',
-	'NOT_WATCHING_TOPIC'				=> 'Não se inscreveu para receber atualizações deste Tópico.',
-	'NOTIFY_ADMIN'						=> 'Por favor notifique o Administrador ou webmaster deste Fórum.',
-	'NOTIFY_ADMIN_EMAIL'				=> 'Por favor notifique o Administrador ou webmaster deste Fórum: <a href="mailto:%1$s">%1$s</a>',
+	'NOT_WATCHING_FORUM'				=> 'Já não se encontra a receber atualizações deste Fórum.',
+	'NOT_WATCHING_TOPIC'				=> 'Já não se encontra a receber atualizações deste Tópico.',
+	'NOTIFY_ADMIN'						=> 'Por favor, notifique o Administrador ou webmaster deste Fórum.',
+	'NOTIFY_ADMIN_EMAIL'				=> 'Por favor, notifique o Administrador ou webmaster deste Fórum: <a href="mailto:%1$s">%1$s</a>',
 	'NO_ACCESS_ATTACHMENT'				=> 'Não está autorizado a aceder este Ficheiro.',
 	'NO_ACTION'							=> 'Nenhuma ação especificada.',
 	'NO_ADMINISTRATORS'					=> 'Este Fórum não tem Administradores.',
@@ -392,7 +392,7 @@ $lang = array_merge($lang, array(
 	'NO_FEED_ENABLED'					=> 'Os Feeds não estão disponíveis neste Fórum.',
 	'NO_FEED'							=> 'O Feed solicitado não está disponível.',
 	'NO_SUBJECT'						=> 'Sem assunto.',
-	'NO_SUCH_SEARCH_MODULE'				=> 'A Pesquisa especifica não existe.',
+	'NO_SUCH_SEARCH_MODULE'				=> 'A Pesquisa especificada não existe.',
 	'NO_SUPPORTED_AUTH_METHODS'			=> 'Nenhum método de autenticação suportado.',
 	'NO_TOPIC'							=> 'Este Tópico não existe.',
 	'NO_TOPIC_FORUM'					=> 'Este Tópico ou Fórum não existem.',
@@ -413,12 +413,12 @@ $lang = array_merge($lang, array(
 	),	
 	
 	'OCCUPATION'							=> 'Ocupação',
-	'OFFLINE'							=> 'Offline',
-	'ONLINE'							=> 'Online',
-	'ONLINE_BUDDIES'					=> 'Amigos Online',
-	'ONLINE_USERS_TOTAL'				=> 'No total há <b>%d</b> Utilizadores online :: ',
-	'ONLINE_USERS_ZERO_TOTAL'			=> 'No total há <b>0</b> Utilizadores online :: ',
-	'ONLINE_USER_TOTAL'					=> 'No total há <b>%d</b> Utilizador online :: ',
+	'OFFLINE'							=> 'Desligado',
+	'ONLINE'							=> 'Ligado',
+	'ONLINE_BUDDIES'					=> 'Amigos ligados',
+	'ONLINE_USERS_TOTAL'				=> 'No total há <b>%d</b> Utilizadores ligados :: ',
+	'ONLINE_USERS_ZERO_TOTAL'			=> 'No total há <b>0</b> Utilizadores ligados :: ',
+	'ONLINE_USER_TOTAL'					=> 'No total há <b>%d</b> Utilizador ligado :: ',
 	'OPTIONS'							=> 'Opções',
 
 	'PAGE_OF'							=> 'Página <b>%1$d</b> de <b>%2$d</b>',
@@ -451,6 +451,7 @@ $lang = array_merge($lang, array(
 	'POST_TIME'							=> 'Data da Mensagem',
 	'POST_TOPIC'						=> 'Criar um novo Tópico',
 	'POST_UNAPPROVED'					=> 'Clique para aprovar a mensagem',
+	'POWERED_BY'						=> 'Desenvolvido por %s',
 	'PREVIEW'							=> 'Prever',
 	'PREVIOUS'							=> 'Anterior',      // Used in pagination
 	'PREVIOUS_STEP'						=> 'Anterior',
@@ -459,6 +460,7 @@ $lang = array_merge($lang, array(
 	'PRIVATE_MESSAGES'					=> 'Mensagens Privadas',
 	'PRIVATE_MESSAGING'					=> 'A enviar Mensagem Privada',
 	'PROFILE'							=> 'Painel de Controlo do Utilizador',
+	'RANK'								=> 'Classificação',
 
 	'READING_FORUM'						=> 'Ver Tópicos em %s',
 	'READING_GLOBAL_ANNOUNCE'			=> 'A ler Anúncio Global',
@@ -469,8 +471,8 @@ $lang = array_merge($lang, array(
 	'RECORD_ONLINE_USERS'				=> 'O recorde de utilizadores online foi de <b>%1$s</b> em %2$s',
 	'REDIRECT'							=> 'Redirecionar',
 	'REDIRECTS'							=> 'Total de redirecionamentos',
-	'REGISTER'							=> 'Registar',
-	'REGISTERED_USERS'					=> '<b>Utilizadores registados online:</b>',
+	'REGISTER'							=> 'Registe-se',
+	'REGISTERED_USERS'					=> '<b>Membros ligados:</b>',
 	'REG_USERS_ONLINE'					=> 'Há %d utilizadores registados e ',
 	'REG_USERS_TOTAL'					=> '%d registados, ',
 	'REG_USERS_TOTAL_AND'				=> '%d registados e ',
@@ -486,7 +488,7 @@ $lang = array_merge($lang, array(
 	'REPLY_WITH_QUOTE'					=> 'Resposta com citações',
 	'REPLYING_GLOBAL_ANNOUNCE'			=> 'A responder a Anúncio Global',
 	'REPLYING_MESSAGE'					=> 'A responder a mensagem em %s',
-	'REPORT_BY'							=> 'Denunciar',
+	'REPORT_BY'							=> 'Denunciada por',
 	'REPORT_POST'						=> 'Denunciar esta mensagem',
 	'REPORTING_POST'					=> 'A denunciar Mensagem',
 	'RESEND_ACTIVATION'					=> 'Reenviar email de Ativação',
@@ -498,31 +500,31 @@ $lang = array_merge($lang, array(
 	'RETURN_TOPIC'						=> 'Clique %saqui%s para voltar ao Tópico',
 	'RETURN_TO'							=> 'Voltar para',
 	'FEED'								=> 'Feed',
-	'FEED_NEWS'							=> 'News',
-	'FEED_TOPICS_ACTIVE'				=> 'Topicos ativos',
-	'FEED_TOPICS_NEW'					=> 'Novos Topicos',
+	'FEED_NEWS'							=> 'Novidades',
+	'FEED_TOPICS_ACTIVE'				=> 'Tópicos ativos',
+	'FEED_TOPICS_NEW'					=> 'Novos Tópicos',
 	'RULES_ATTACH_CAN'					=> 'Enviar anexos: <b>Permitido</b>',
-	'RULES_ATTACH_CANNOT'				=> 'Enviar anexos: <b>Proibído</b>',
+	'RULES_ATTACH_CANNOT'				=> 'Enviar anexos: <b>Proibido</b>',
 	'RULES_DELETE_CAN'					=> 'Apagar Mensagens: <b>Permitido</b>',
-	'RULES_DELETE_CANNOT'				=> 'Apagar Mensagens: <b>Proibído</b>',
+	'RULES_DELETE_CANNOT'				=> 'Apagar Mensagens: <b>Proibido</b>',
 	'RULES_DOWNLOAD_CAN'				=> 'Transferir anexos: <b>Permitido</b>',
-	'RULES_DOWNLOAD_CANNOT'				=> 'Transferir anexos: <b>Proibído</b>',
+	'RULES_DOWNLOAD_CANNOT'				=> 'Transferir anexos: <b>Proibido</b>',
 	'RULES_EDIT_CAN'					=> 'Editar Mensagens: <b>Permitido</b>',
-	'RULES_EDIT_CANNOT'					=> 'Editar Mensagens: <b>Proibído</b>',
+	'RULES_EDIT_CANNOT'					=> 'Editar Mensagens: <b>Proibido</b>',
 	'RULES_LOCK_CAN'					=> 'Bloquear Tópicos: <b>Permitido</b>',
-	'RULES_LOCK_CANNOT'					=> 'Bloquear Tópicos: <b>Proibído</b>',
+	'RULES_LOCK_CANNOT'					=> 'Bloquear Tópicos: <b>Proibido</b>',
 	'RULES_POST_CAN'					=> 'Criar Tópicos: <b>Permitido</b>',
-	'RULES_POST_CANNOT'					=> 'Criar Tópicos: <b>Proibído</b>',
+	'RULES_POST_CANNOT'					=> 'Criar Tópicos: <b>Proibido</b>',
 	'RULES_REPLY_CAN'					=> 'Responder Tópicos: <b>Permitido</b>',
-	'RULES_REPLY_CANNOT'				=> 'Responder Tópicos: <b>Proibído</b>',
+	'RULES_REPLY_CANNOT'				=> 'Responder Tópicos: <b>Proibido</b>',
 	'RULES_VOTE_CAN'					=> 'Votar em votações: <b>Permitido</b>',
-	'RULES_VOTE_CANNOT'					=> 'Votar em votações: <b>Proibído</b>',
+	'RULES_VOTE_CANNOT'					=> 'Votar em votações: <b>Proibido</b>',
 
 	'SEARCH'							=> 'Pesquisar',
 	'SEARCH_MINI'						=> 'Pesquisar…',
 	'SEARCH_ADV'						=> 'Pesquisa avançada',
 	'SEARCH_ADV_EXPLAIN'				=> 'Ver opções avançadas de pesquisa',
-	'SEARCH_KEYWORDS'					=> 'Palavra Chave',
+	'SEARCH_KEYWORDS'					=> 'Palavra-Chave',
 	'SEARCHING_FORUMS'					=> 'Pesquisando nos Fóruns',
 	'SEARCH_ACTIVE_TOPICS'				=> 'Ver Tópicos ativos',
 	'SEARCH_FOR'						=> 'Pesquisar por',
@@ -532,7 +534,7 @@ $lang = array_merge($lang, array(
 	'SEARCH_SELF'						=> 'Ver as minhas Mensagens',
 	'SEARCH_TOPIC'						=> 'Pesquisar neste Tópico…',
 	'SEARCH_UNANSWERED'					=> 'Ver mensagens sem resposta',
-	'SEARCH_UNREAD'						=> 'Ver mensagens não lidas',
+	'SEARCH_UNREAD'						=> 'Ver mensagens por ler',
 	'SEARCH_USER_POSTS'					=> 'Pesquisar mensagens dos utilizadores',
 	'SECONDS'							=> 'Segundos',
 	'SELECT'							=> 'Selecionar',
@@ -551,12 +553,12 @@ $lang = array_merge($lang, array(
 	'SORT_BY'							=> 'Ordenar por',
 	'SORT_JOINED'						=> 'Data de Registo',
 	'SORT_LOCATION'						=> 'Localização',
-	'SORT_RANK'							=> 'Rank',
+	'SORT_RANK'							=> 'Classificação',
 	'SORT_POSTS'						=> 'Mensagens',
 	'SORT_TOPIC_TITLE'					=> 'Título do Tópico',
 	'SORT_USERNAME'						=> 'Utilizador',
 	'SPLIT_TOPIC'						=> 'Dividir Tópico',
-	'SQL_ERROR_OCCURRED'				=> 'Ocorreu um erro SQL enquanto esta página era processava. Contate um Administrador se o problema persistir',
+	'SQL_ERROR_OCCURRED'				=> 'Ocorreu um erro SQL enquanto esta página era processada. Contate um Administrador se o problema persistir',
 	'STATISTICS'						=> 'Estatísticas do Fórum:',
 	'START_WATCHING_FORUM'				=> 'Observar Fórum',
 	'START_WATCHING_TOPIC'				=> 'Observar Tópico',
@@ -633,7 +635,7 @@ $lang = array_merge($lang, array(
 	'TOTAL_ATTACHMENTS'					=> 'Anexo(s)',
 	'TOTAL_LOG'							=> '1 registo',
 	'TOTAL_LOGS'						=> '%d registos',
-	'TOTAL_NO_PM'						=> '0 Mensagens Privadas no total',
+	'TOTAL_NO_PM'						=> 'Sem Mensagens Privadas',
 	'TOTAL_PM'							=> '1 Mensagem Privada no total',
 	'TOTAL_PMS'							=> '$d Mensagens Privadas no total',
 	'TOTAL_POSTS'						=> 'Total de Mensagens',
@@ -655,10 +657,10 @@ $lang = array_merge($lang, array(
 	'UNREAD_PMS'						=> '<b>%d</b> mensagens não lidas',
 	'UNREAD_POST'						=> 'Mensagem não lida',
 	'UNREAD_POSTS'						=> 'Mensagens não lidas',
-	'UNWATCH_FORUM_CONFIRM'				=> 'Tem certeza que deseja cancelar a assinatura deste forum?',
-	'UNWATCH_FORUM_DETAILED'			=> 'Tem certeza que deseja cancelar a assinatura do forum “%s”?',
-	'UNWATCH_TOPIC_CONFIRM'				=> 'Tem certeza que deseja cancelar a assinatura deste Topico?',
-	'UNWATCH_TOPIC_DETAILED'			=> 'Tem certeza que deseja cancelar a assinatura do Topico “%s”?',
+	'UNWATCH_FORUM_CONFIRM'				=> 'Tem certeza que deseja cancelar a assinatura deste fórum?',
+	'UNWATCH_FORUM_DETAILED'			=> 'Tem certeza que deseja cancelar a assinatura do fórum “%s”?',
+	'UNWATCH_TOPIC_CONFIRM'				=> 'Tem certeza que deseja cancelar a assinatura deste Tópico?',
+	'UNWATCH_TOPIC_DETAILED'			=> 'Tem certeza que deseja cancelar a assinatura do Tópico “%s”?',
 	'UNWATCHED_FORUMS'					=> 'Já não se encontra a observar este Fórum.',
 	'UNWATCHED_TOPICS'					=> 'Já não se encontra a observar este Tópico.',
 	'UNWATCHED_FORUMS_TOPICS'			=> 'Já não se encontra a observar as entradas selecionadas.',
@@ -687,10 +689,10 @@ $lang = array_merge($lang, array(
 	'VIEWING_PRIVATE_MESSAGES'			=> 'A Ver Mensagens Privadas',
 	'VIEWING_REGISTER'					=> 'Registar uma nova conta',
 	'VIEWING_UCP'						=> 'A Ver o Painel de Controlo do Utilizador',
-	'VIEWS'								=> 'Exibições',
+	'VIEWS'								=> 'Visualizações',
 	'VIEW_BOOKMARKS'					=> 'Ver Favoritos',
 	'VIEW_FORUM_LOGS'					=> 'Ver registos',
-	'VIEW_LATEST_POST'					=> 'A ver últimas Mensagens',
+	'VIEW_LATEST_POST'					=> 'Veja a última Mensagem',
 	'VIEW_NEWEST_POST'					=> 'A ver Mensagens Novas',
 	'VIEW_NOTES'						=> 'Ver Notas do Utilizador',
 	'VIEW_ONLINE_TIME'					=> 'Informação relativa aos utilizadores ativos no último %d minuto',
@@ -781,7 +783,7 @@ $lang = array_merge($lang, array(
 		'Jul'							=> 'jul',
 		'Aug'							=> 'ago',
 		'Sep'							=> 'set',
-		'Ot'							=> 'out',
+		'Oct'							=> 'out',
 		'Nov'							=> 'nov',
 		'Dec'							=> 'dez',
 	),
