@@ -4,7 +4,7 @@
 * groups [Português]
 *
 * @package language
-* @version 1.0.2
+* @version 1.0.4
 * @Traduzido por: http://phpbbportugal.com - segundo as normas do Acordo Ortográfico
 * @copyright (c) 2005 phpBB Group
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
@@ -52,7 +52,7 @@ $lang = array_merge($lang, array(
 	'GROUP_HIDDEN'						=> 'Escondido',
 	'GROUP_INFORMATION'					=> 'Informações do Grupo',
 	'GROUP_IS_CLOSED'					=> 'Este é um Grupo fechado, não podem entrar novos Utilizadores automaticamente.',
-	'GROUP_IS_FREE'						=> 'Este é um Grupo aberto, todos os Utilizadores são bem vindos',
+	'GROUP_IS_FREE'						=> 'Este é um Grupo aberto, todos os Utilizadores são bem-vindos',
 	'GROUP_IS_HIDDEN'					=> 'Este é um Grupo invisível, só os seus membros podem vê-lo.',
 	'GROUP_IS_OPEN'						=> 'Este é um Grupo aberto, podem entrar novos Utilizadores.',
 	'GROUP_IS_SPECIAL'					=> 'Este é um Grupo especial, só o Administrador pode adicionar novos Utilizadores.',
@@ -66,7 +66,7 @@ $lang = array_merge($lang, array(
 	'GROUP_MEMBERS'						=> 'Utilizadores do Grupo',
 	'GROUP_NAME'						=> 'Nome do Grupo',
 	'GROUP_OPEN'						=> 'Aberto',
-	'GROUP_RANK'						=> 'Rank do Grupo',
+	'GROUP_RANK'						=> 'Classificação do Grupo',
 	'GROUP_RESIGN_MEMBERSHIP'			=> 'Remover Utilizadores do Grupo',
 	'GROUP_RESIGN_MEMBERSHIP_CONFIRM'	=> 'Tem a certeza de que deseja remover o Utilizador pendente do Grupo selecionado?',
 	'GROUP_RESIGN_PENDING'				=> 'Remover um Utilizador pendente',
